@@ -10,6 +10,7 @@ function ScormStudioXBlock(runtime, element) {
         var weight = $(element).find('input[name=weight]').val();
         var width = $(element).find('input[name=width]').val();
         var height = $(element).find('input[name=height]').val();
+        var fullscreen_on_launch = $(element).find('select[name=fullscreen_on_launch]').val();
 
         form_data.append('file', file_data);
         form_data.append('display_name', display_name);
@@ -17,10 +18,12 @@ function ScormStudioXBlock(runtime, element) {
         form_data.append('weight', weight);
         form_data.append('width', width);
         form_data.append('height', height);
+        form_data.append('fullscreen_on_launch', fullscreen_on_launch);
         runtime.notify('save', {
             state: 'start'
         });
 
+        $(this).addClass("disabled");
         $.ajax({
             url: handlerUrl,
             dataType: 'json',
@@ -29,6 +32,9 @@ function ScormStudioXBlock(runtime, element) {
             processData: false,
             data: form_data,
             type: "POST",
+            complete: function() {
+                $(this).removeClass("disabled");
+            },
             success: function(response) {
                 if (response.errors.length > 0) {
                     response.errors.forEach(function(error) {
